@@ -15,12 +15,12 @@
 #' @param dml list of design matrices created by \code{\link{create.dm}} from
 #' formula and design data
 #' @param model_data a list of all the relevant data for fitting the model including
-#' imat, Phi.dm, p.dm, Psi.dm, Phi.fixed, p.fixed, Psi.fixed and time.intervals. It is used to save values
+#' imat, S.dm,p.dm,Psi.dm,S.fixed,p.fixed,Psi.fixed and time.intervals. It is used to save values
 #' and avoid accumulation again if the model was re-rerun with an additional call to cjs when
 #' using autoscale or re-starting with initial values.  It is stored with returned model object.
 #' @param parameters equivalent to \code{model.parameters} in \code{\link{crm}}
 #' @param accumulate if TRUE will accumulate capture histories with common
-#' value and with a common design matrix for Phi and p to speed up execution
+#' value and with a common design matrix for S and p to speed up execution
 #' @param initial list of initial values for parameters if desired; if each is a named vector
 #' from previous run it will match to columns with same name
 #' @param method method to use for optimization; see \code{optim}
@@ -36,6 +36,7 @@
 #' @param re if TRUE creates random effect model admbcjsre.tpl and runs admb optimizer
 #' @param compile if TRUE forces re-compilation of tpl file
 #' @param extra.args optional character string that is passed to admb if use.admb==TRUE
+#' @param clean if TRUE, deletes the tpl and executable files for amdb if use.admb=T
 #' @param ... any remaining arguments are passed to additional parameters
 #' passed to \code{optim} or \code{\link{cjs.lnl}}
 #' @import R2admb
@@ -45,7 +46,7 @@
 #' likelihood} \item{AIC}{lnl + 2* number of parameters}
 #' \item{convergence}{result from \code{optim}; if 0 \code{optim} thinks it
 #' converged} \item{count}{\code{optim} results of number of function
-#' evaluations} \item{reals}{dataframe of data and real Phi and p estimates for
+#' evaluations} \item{reals}{dataframe of data and real S and p estimates for
 #' each animal-occasion excluding those that occurred before release}
 #' \item{vcv}{var-cov matrix of betas if hessian=TRUE was set}
 #' @author Jeff Laake <jeff.laake@@noaa.gov>
@@ -53,21 +54,22 @@
 #' 
 mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL,method,
 		hessian=FALSE,debug=FALSE,chunk_size=1e7,refit,itnmax=NULL,control=NULL,scale,
-		use.admb=FALSE,re=FALSE,compile=FALSE,extra.args="",...)
+		use.admb=FALSE,re=FALSE,compile=FALSE,extra.args="",clean=TRUE,...)
 {
 	accumulate=FALSE
 	nocc=x$nocc
 #  Time intervals has been changed to a matrix (columns=intervals,rows=animals)
-#  so that the initial time interval can vary by animal; use default of 1 if none are in Phi.dmdf
-	time.intervals=matrix(x$time.intervals,nrow=nrow(x$data),ncol=nocc-1,byrow=TRUE)
+#  so that the initial time interval can vary by animal; use x$intervals if none are in ddl$Phi
 	if(!is.null(ddl$Phi$time.interval))
 		time.intervals=matrix(ddl$Phi$time.interval,nrow(x$data),ncol=nocc-1,byrow=TRUE)
-#  If no fixed real parameters are specified, assign dummy unused ones with negative indices and 0 value
-	if(is.null(parameters$Phi$fixed))
-		parameters$Phi$fixed=matrix(c(-1,-1,0),nrow=1,ncol=3)
-	if(is.null(parameters$p$fixed))
-		parameters$p$fixed=matrix(c(-1,-1,0),nrow=1,ncol=3)  
-#  Store data from x into x
+	else
+	if(is.vector(x$time.intervals))
+		time.intervals=matrix(x$time.intervals,nrow=nrow(x$data),ncol=nocc-1,byrow=TRUE)
+	else
+		time.intervals=x$time.intervals
+#  Create fixed matrices in parameters
+	parameters=create.fixed.matrix(ddl,parameters)
+#  Store data from x$data into x
 	strata.labels=x$strata.labels
 	uS=x$unobserved
 	x=x$data
@@ -77,18 +79,18 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 #  get first and last vectors, loc and chmat with process.ch and store in imat
 	ch=x$ch
 	imat=process.ch(ch,freq,all=FALSE)
-	chmat=matrix((unlist(strsplit(ch,""))),byrow=TRUE,ncol=nocc,nrow=length(ch))
+	chmat=matrix((unlist(strsplit(ch,","))),byrow=TRUE,ncol=nocc,nrow=length(ch))
 	for(nlabel in 1:length(strata.labels))
 		chmat=t(apply(chmat,1,sub,pattern=strata.labels[nlabel],replacement=nlabel))
 #  Use specified initial values or create if null
 	if(is.null(initial))
-		par=list(Psi=rep(0,ncol(dml$Psi)),
-		         p=rep(0,ncol(dml$p)),
-		         Phi=rep(0,ncol(dml$Phi)))
+		par=list(Psi=rep(0,ncol(dml$Psi$fe)),
+		         p=rep(0,ncol(dml$p$fe)),
+		         S=rep(0,ncol(dml$S$fe)))
 	else
-		par=set.initial(names(dml),dml,initial)
+		par=set.initial(names(dml),dml,initial)$par
 #  Create list of model data for optimization
-	model_data=list(Phi.dm=dml$Phi,p.dm=dml$p,Psi.dm=dml$Psi,imat=imat,Phi.fixed=parameters$Phi$fixed,
+	model_data=list(S.dm=dml$S$fe,p.dm=dml$p$fe,Psi.dm=dml$Psi$fe,imat=imat,S.fixed=parameters$S$fixed,
 			p.fixed=parameters$p$fixed,Psi.fixed=parameters$Psi$fixed,time.intervals=time.intervals)
 #   If data are to be accumulated based on ch and design matrices do so here;
 	if(accumulate)
@@ -100,8 +102,8 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 	}else
 		model_data.save=model_data
 #   Create links  -- not used at present; idea here is to use sin links for parameters where you can   
-#   Phi.links=create.links(Phi.dm)
-#   Phi.links=which(Phi.links==1)
+#   S.links=create.links(S.dm)
+#   S.links=which(S.links==1)
 #   p.links=create.links(p.dm)
 #   p.links=which(p.links==1)
 #  Scale the design matrices and parameters with either input scale or computed scale
@@ -109,10 +111,14 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
     scale=1
 	scale=set.scale(names(dml),model_data,scale)
 	model_data=scale.dm(model_data,scale)
+	if(R.Version()$os=="mingw32")
+		ext=".exe"
+	else
+		ext=""
 	# see if admb can be found; this is not a complete test but should catch the novice user who has
 	# not setup admb at all
-	if(Sys.which("tpl2cpp.exe")=="")stop("admb not found; setup links to admb and c++ compiler with environment variables or put in path") 
-	# cleanup any leftover admbcjs files
+    if(Sys.which(paste("tpl2cpp",ext,sep=""))=="") 
+	    stop("admb not found; setup links to admb and c++ compiler with environment variables or put in path")
 	sdir=system.file(package="marked")
 	# if multistate.tpl is not available copy from the package directory
 	if(!re)
@@ -123,10 +129,17 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 		if(!hessian)message("ignoring hessian setting; set to TRUE")
 		hessian=TRUE
 	}
+    # cleanup any leftover admbcjs files
 	clean_admb(tpl)
+	# if argument clean is TRUE, delete exe and TPL files as well
+	if(clean)
+	{
+		if(file.exists(paste(tpl,".tpl",sep=""))) unlink(paste(tpl,".tpl",sep=""))
+		if(file.exists(paste(tpl,ext,sep=""))) unlink(paste(tpl,ext,sep=""))
+	}
 	if(!file.exists(paste(tpl,".tpl",sep="")))
 		file.copy(file.path(sdir,paste(tpl,".tpl",sep="")),file.path(getwd(),paste(tpl,".tpl",sep="")),overwrite=TRUE)
-	if(!file.exists(paste(tpl,".exe",sep=""))|compile)
+	if(!file.exists(paste(tpl,ext,sep=""))|compile)
 		compile_admb(tpl,re=re)
 	# create .dat file to write its contents 
 	con=file(paste(tpl,".dat",sep=""),open="wt")
@@ -153,9 +166,9 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 		if(any(model_data$imat$freq!=1))stop("\n cannot use random effects with frequency >1")
 	}
 	write(t(model_data$time.intervals),con,ncolumns=nocc-1,append=TRUE)
-	# Phi design matrix
-	write(ncol(model_data$Phi.dm),con,append=TRUE)
-	write(t(model_data$Phi.dm),con,ncolumns=ncol(model_data$Phi.dm),append=TRUE)
+	# S design matrix
+	write(ncol(model_data$S.dm),con,append=TRUE)
+	write(t(model_data$S.dm),con,ncolumns=ncol(model_data$S.dm),append=TRUE)
 	# p design matrix
     # zero out dm if any unobserved stratum; only done to remove unneeded columns
     if(uS>0)
@@ -170,7 +183,7 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 	write(t(model_data$p.dm),con,ncolumns=ncol(model_data$p.dm),append=TRUE)
 	# Psi design matrix
 	# zero out subtracted stratum and remove any unneeded columns
-    model_data$Psi.dm[ddl$Psi$stratum==ddl$Psi$tostratum,]=0
+    model_data$Psi.dm[!is.na(ddl$Psi$fix),]=0
 	select=vector("logical",length=ncol(model_data$Psi.dm))
 	for (i in 1:ncol(model_data$Psi.dm))
 		select[i]=any(model_data$Psi.dm[,i]!=0)
@@ -179,7 +192,7 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 	write(t(model_data$Psi.dm),con,ncolumns=ncol(model_data$Psi.dm),append=TRUE)
 	close(con)
 	con=file(paste(tpl,".pin",sep=""),open="wt")
-	write(par$Phi,con,ncolumns=length(par$Phi),append=FALSE)
+	write(par$S,con,ncolumns=length(par$S),append=FALSE)
 	write(par$p,con,ncolumns=length(par$p),append=TRUE)
 	write(par$Psi,con,ncolumns=length(par$Psi),append=FALSE)
 	close(con)   
@@ -193,7 +206,7 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 #  Restore non-accumulated, non-scaled dm's etc
    res$model_data=model_data.save
 #  Assign S3 class values and return
-   #class(res)=c("crm","mle","mscjs")
+   class(res)=c("crm","admb","mle","mscjs")
    return(res)
 }
 
