@@ -154,7 +154,6 @@ function(data,begin.time=1,model="CJS",mixtures=1,groups=NULL,allgroups=FALSE,ag
 initial.ages=c(0),time.intervals=NULL,nocc=NULL,accumulate=TRUE,strata.labels=NULL)
 {
    model=toupper(model)
-   if(model%in%c("probitCJS","probitMsCJS"))accumulate=FALSE
    dataname=substitute(data)
   #
   #  Compute number of occasions and check validity of model
@@ -176,6 +175,8 @@ initial.ages=c(0),time.intervals=NULL,nocc=NULL,accumulate=TRUE,strata.labels=NU
    #  Setup model
    #
    model.list=setup.model(model,nocc,mixtures)
+   # regardless of user input for accumulate if it is FALSE in model.list set to FALSE;
+   # the bayesian models cannot deal with accumulation
    if(!model.list$accumulate)accumulate=FALSE
    ch.values=unique(unlist(strsplit(data$ch,",")))
    #  If no strata in model then only 0,1 are acceptable values
@@ -278,14 +279,24 @@ initial.ages=c(0),time.intervals=NULL,nocc=NULL,accumulate=TRUE,strata.labels=NU
 					return(c(as.numeric(factor(xx[ich],levels=model.list$hmm$ObsLevels))-1,ich))
 				}))
    else
-	   start=t(sapply(data$ch,function(x){
+	   if(is.null(model.list$hmm$obs_strata_map))
+	       start=t(sapply(data$ch,function(x){
 						   xx=strsplit(x,",")[[1]]
 						   ich=min(which(strsplit(x,",")[[1]]!="0"))
 						   return(c(match(xx[ich],model.list$hmm$strata.labels),ich))
 					   }))
+       else
+		   start=t(sapply(data$ch,function(x){
+							   xx=strsplit(x,",")[[1]]
+							   ich=min(which(strsplit(x,",")[[1]]!="0"))
+							   return(c(model.list$hmm$obs_strata_map[match(xx[ich],model.list$hmm$ObsLevels)],ich))
+						   }))
    
    # create encounter history matrix
-   ehmat=t(sapply(strsplit(data$ch,","),function(x) as.numeric(factor(x,levels=model.list$hmm$ObsLevels))))
+   if(model.list$IShmm)
+      ehmat=t(sapply(strsplit(data$ch,","),function(x) as.numeric(factor(x,levels=model.list$hmm$ObsLevels))))
+   else
+	  ehmat=process.ch(data$ch)$chmat
    #
    #  If there are no factors then
    #     if already has freq variable return the input data set as a list
@@ -433,11 +444,20 @@ initial.ages=c(0),time.intervals=NULL,nocc=NULL,accumulate=TRUE,strata.labels=NU
 			stop("length of begin.time must either be 1 or match number of groups")
 		else
 		    data$begin.time=begin.time[data$group]
-        plist=list(data=data,model=model,mixtures=mixtures,freq=freqmat,
-                   nocc=nocc, nocc.secondary=nocc.secondary, time.intervals=time.intervals,begin.time=begin.time,
-                   initial.ages=init.ages,group.covariates=group.covariates,start=start,ehmat=ehmat)
+		plist=list(data=data,model=model,mixtures=mixtures,freq=freqmat,
+				nocc=nocc, nocc.secondary=nocc.secondary, time.intervals=time.intervals,begin.time=begin.time,
+				initial.ages=init.ages,group.covariates=group.covariates,start=start,ehmat=ehmat)
         if(model.list$strata)plist=c(plist,list(strata=model.list$strata,strata.labels=model.list$strata.labels,unobserved=unobserved))
-        if(!is.null(model.list$hmm)) plist=c(plist,model.list$hmm)
+        if(!is.null(model.list$hmm)) 
+		{
+			if(!is.null(model.list$hmm$strata.labels))
+		    {
+		        plist$strata.labels=model.list$hmm$strata.labels	
+			    plist=c(plist,model.list$hmm[!names(model.list$hmm)%in%"strata.labels"])
+			}
+			else
+				plist=c(plist,model.list$hmm)
+		}
         return(plist) 
     }
 }
@@ -531,6 +551,7 @@ accumulate_data <- function(data)
 	freq=sapply(split(data$freq, pasted.data),sum)
 	x=unique(x[order(pasted.data),,drop=FALSE])
 	x$freq=freq
-	cat(nx,"capture histories collapsed into ",nrow(x),"\n")
+	message(nx, " capture histories collapsed into ", nrow(x), "\n", appendLF=FALSE)
 	return(x)	
 }
+
